@@ -1,4 +1,4 @@
-"""The clients that interact with the service APIs."""
+"""The clients that interact with the streaming service APIs."""
 
 import base64
 import binascii
@@ -37,6 +37,7 @@ from .exceptions import (
     InvalidAppSecretError,
     InvalidQuality,
     MissingCredentials,
+    NonStreamable,
 )
 from .spoofbuz import Spoofer
 from .utils import gen_threadsafe_session, get_quality, safe_get
@@ -115,7 +116,6 @@ class QobuzClient(Client):
         :type pwd: str
         :param kwargs: app_id: str, secrets: list, return_secrets: bool
         """
-        # TODO: make this faster
         secho(f"Logging into {self.source}", fg="green")
         email: str = kwargs["email"]
         pwd: str = kwargs["pwd"]
@@ -567,7 +567,14 @@ class DeezerClient(Client):
         }
 
         token = track_info["TRACK_TOKEN"]
-        url = self.client.get_track_url(token, format_str)
+        try:
+            url = self.client.get_track_url(token, format_str)
+        except deezer.WrongLicense:
+            raise NonStreamable(
+                "The requested quality is not available with your subscription. "
+                "Deezer HiFi is required for quality 2. Otherwise, the maximum "
+                "quality allowed is 1."
+            )
 
         if url is None:
             url = self._get_encrypted_file_url(
@@ -870,7 +877,7 @@ class TidalClient(Client):
         }
         resp = self._api_post(f"{TIDAL_AUTH_URL}/device_authorization", data)
 
-        if "status" in resp and resp["status"] != 200:
+        if resp.get("status", 200) != 200:
             raise Exception(f"Device authorization failed {resp}")
 
         self.device_code = resp["deviceCode"]
@@ -1182,7 +1189,7 @@ class SoundCloudClient(Client):
             raise Exception
 
         if track["downloadable"] and track["has_downloads_left"]:
-            r = self._get(f"tracks/{track['id']}/download")[0]
+            r = self._get(f"tracks/{track['id']}/download").json()
             return {"url": r["redirectUri"], "type": "original"}
 
         else:
