@@ -1,5 +1,7 @@
 """Constants that are kept in one place."""
 
+import base64
+
 import mutagen.id3 as id3
 
 AGENT = "Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:83.0) Gecko/20100101 Firefox/83.0"
@@ -128,6 +130,7 @@ TRACK_KEYS = (
     "composer",
     "title",
     "albumcomposer",
+    "explicit",
 )
 ALBUM_KEYS = (
     "albumartist",
@@ -173,8 +176,10 @@ MEDIA_TYPES = {"track", "album", "artist", "label", "playlist", "video"}
 COVER_SIZES = ("thumbnail", "small", "large", "original")
 
 TIDAL_CLIENT_INFO = {
-    "id": "aR7gUaTK1ihpXOEP",
-    "secret": "eVWBEkuL2FCjxgjOkR3yK0RYZEbcrMXRc2l8fU3ZCdE=",
+    "id": base64.b64decode("OFNFWldhNEoxTlZDNVU1WQ==").decode("iso-8859-1"),
+    "secret": base64.b64decode(
+        "b3dVWURreGRkeis5RnB2R1gyNERseEVDTnRGRU1CeGlwVTBsQmZyYnE2MD0="
+    ).decode("iso-8859-1"),
 }
 
 QOBUZ_BASE = "https://www.qobuz.com/api.json/0.2"
