@@ -1,12 +1,8 @@
-"""Bases that handle parsing and downloading media.
-
-These are the lower level classes that are handled by Album, Playlist,
-and the other objects. They can also be downloaded individually, for example,
-as a single track.
-"""
+"""Bases that handle parsing and downloading media. """
 
 import abc
 import concurrent.futures
+import hashlib
 import logging
 import os
 import re
@@ -986,6 +982,7 @@ class YoutubeVideo(Media):
     """Dummy class implemented for consistency with the Media API."""
 
     id = None
+    downloaded_ids = set()
 
     class DummyClient:
         """Used because YouTube downloads use youtube-dl, not a client."""
@@ -1055,6 +1052,7 @@ class YoutubeVideo(Media):
             )
             pv.wait()
         p.wait()
+        self.downloaded_ids.add(self.id)
 
     def load_meta(self, *args, **kwargs):
         """Return None.
@@ -1079,9 +1077,15 @@ class YoutubeVideo(Media):
     def convert(self, *args, **kwargs):
         raise NotImplementedError
 
+    def type(self):
+        return "youtubevideo"
+
     def __repr__(self, *args, **kwargs):
         return f"YoutubeVideo({self.url})"
 
+    def __str__(self):
+        return repr(self)
+
     def __bool__(self):
         """Return True."""
         return True
@@ -1491,7 +1495,11 @@ class Album(Tracklist, Media):
         """
         # Generate the folder name
         self.folder_format = kwargs.get("folder_format", FOLDER_FORMAT)
-        self.quality = min(kwargs.get("quality", 3), self.client.max_quality)
+        self.quality = min(
+            kwargs.get("quality", 3),
+            self.client.max_quality,
+            self.meta.get("quality", 5),
+        )
 
         self.container = get_container(self.quality, self.client.source)
         # necessary to format the folder
@@ -1517,8 +1525,8 @@ class Album(Tracklist, Media):
             self.folder,
             kwargs.get("keep_hires_cover", True),
             (
-                kwargs.get("max_artwork_width", 999999),
-                kwargs.get("max_artwork_height", 999999),
+                kwargs.get("max_artwork_width", 1e9),
+                kwargs.get("max_artwork_height", 1e9),
             ),
         )
 
@@ -1784,7 +1792,9 @@ class Playlist(Tracklist, Media):
 
         elif self.client.source == "tidal":
             self.name = self.meta["title"]
-            self.image = tidal_cover_url(self.meta["image"] or self.meta['squareImage'], 640)
+            self.image = tidal_cover_url(
+                self.meta["image"] or self.meta["squareImage"], 640
+            )
             self.creator = safe_get(self.meta, "creator", "name", default="TIDAL")
 
             tracklist = self.meta["tracks"]
@@ -2303,9 +2313,21 @@ def _choose_and_download_cover(
     downsize: Tuple[int, int] = (999999, 999999),
 ) -> str:
     # choose optimal cover size and download it
-    temp_cover_path = os.path.join(
-        gettempdir(), f"cover_{hash(cover_urls.values())}.jpg"
-    )
+
+    hashcode: str = hashlib.md5(
+        "".join(
+            sorted(
+                map(
+                    str,
+                    cover_urls.values(),
+                )
+            )
+        ).encode("utf-8", errors="ignore")
+    ).hexdigest()
+    # hashcode: str = hashlib.md5(str(sorted_list(cover_urls.values())).encode('utf-8', errors='replace')).hexdigest()
+
+    temp_cover_path = os.path.join(gettempdir(), f"cover_{hashcode}.jpg")
+
     secho(f"Downloading cover art ({preferred_size})", bold=True)
 
     assert (
